==> v10.3.1.tar.gz: barker/bookie/src/app/menu-category/menu-category.service.ts <==
import { HttpClient, HttpHeaders, HttpParams } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { catchError } from 'rxjs/operators';

import { BeerSaleReport } from '../beer-sale-report/beer-sale-report';
import { ErrorLoggerService } from '../core/error-logger.service';
import { MenuCategory } from '../core/menu-category';

const httpOptions = {
  headers: new HttpHeaders({ 'Content-Type': 'application/json' }),
};
const url = '/api/menu-categories';
const serviceName = 'MenuCategoryService';

@Injectable({
  providedIn: 'root',
})
export class MenuCategoryService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {}

  get(id: string | null): Observable<MenuCategory> {
    const getUrl: string = id === null ? url : `${url}/${id}`;
    return this.http
      .get<MenuCategory>(getUrl)
      .pipe(
        catchError(this.log.handleError(serviceName, `get id=${id}`)),
      ) as Observable<MenuCategory>;
  }

  list(shouldHaveActiveProducts: boolean | undefined): Observable<MenuCategory[]> {
    const options = { params: new HttpParams() };
    if (!!shouldHaveActiveProducts) {
      options.params = options.params.set('p', 'true');
    }
    return this.http
      .get<MenuCategory[]>(`${url}/list`, options)
      .pipe(catchError(this.log.handleError(serviceName, 'list'))) as Observable<MenuCategory[]>;
  }

  save(menuCategory: MenuCategory): Observable<MenuCategory> {
    return this.http
      .post<MenuCategory>(url, menuCategory, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'save'))) as Observable<MenuCategory>;
  }

  update(menuCategory: MenuCategory): Observable<MenuCategory> {
    return this.http
      .put<MenuCategory>(`${url}/${menuCategory.id}`, menuCategory, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'update'))) as Observable<MenuCategory>;
  }

  updateSortOrder(list: MenuCategory[]): Observable<boolean> {
    return this.http
      .post<MenuCategory[]>(`${url}/list`, list, httpOptions)
      .pipe(
        catchError(this.log.handleError(serviceName, 'updateSortOrder')),
      ) as Observable<boolean>;
  }

  saveOrUpdate(menuCategory: MenuCategory): Observable<MenuCategory> {
    if (!menuCategory.id) {
      return this.save(menuCategory);
    }
    return this.update(menuCategory);
  }

  delete(id: string): Observable<MenuCategory> {
    return this.http
      .delete<MenuCategory>(`${url}/${id}`, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'delete'))) as Observable<MenuCategory>;
  }
}

==> v11.6.2.tar.gz: barker/bookie/src/app/menu-category/menu-category.service.ts <==
import { HttpClient, HttpHeaders, HttpParams } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';
import { MenuCategory } from '../core/menu-category';

const httpOptions = {
  headers: new HttpHeaders({ 'Content-Type': 'application/json' }),
};
const url = '/api/menu-categories';
const serviceName = 'MenuCategoryService';

@Injectable({
  providedIn: 'root',
})
export class MenuCategoryService {
  constructor(
    private http: HttpClient,
    private log: ErrorLoggerService,
  ) {}

  get(id: string | null): Observable<MenuCategory> {
    const getUrl: string = id === null ? url : `${url}/${id}`;
    return this.http
      .get<MenuCategory>(getUrl)
      .pipe(catchError(this.log.handleError(serviceName, `get id=${id}`))) as Observable<MenuCategory>;
  }

  list(shouldHaveActiveProducts: boolean | undefined): Observable<MenuCategory[]> {
    const options = { params: new HttpParams() };
    if (shouldHaveActiveProducts) {
      options.params = options.params.set('p', 'true');
    }
    return this.http
      .get<MenuCategory[]>(`${url}/list`, options)
      .pipe(catchError(this.log.handleError(serviceName, 'list'))) as Observable<MenuCategory[]>;
  }

  save(menuCategory: MenuCategory): Observable<MenuCategory> {
    return this.http
      .post<MenuCategory>(url, menuCategory, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'save'))) as Observable<MenuCategory>;
  }

  update(menuCategory: MenuCategory): Observable<MenuCategory> {
    return this.http
      .put<MenuCategory>(`${url}/${menuCategory.id}`, menuCategory, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'update'))) as Observable<MenuCategory>;
  }

  updateSortOrder(list: MenuCategory[]): Observable<boolean> {
    return this.http
      .post<MenuCategory[]>(`${url}/list`, list, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'updateSortOrder'))) as Observable<boolean>;
  }

  saveOrUpdate(menuCategory: MenuCategory): Observable<MenuCategory> {
    if (!menuCategory.id) {
      return this.save(menuCategory);
    }
    return this.update(menuCategory);
  }

  delete(id: string): Observable<MenuCategory> {
    return this.http
      .delete<MenuCategory>(`${url}/${id}`, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'delete'))) as Observable<MenuCategory>;
  }
}
